@@ -25,7 +25,7 @@ from tempfile import gettempdir, NamedTemporaryFile, TemporaryDirectory
 from airflow import configuration as conf
 from airflow.exceptions import AirflowException
 from airflow.utils.log.logging_mixin import LoggingMixin
-from airflow.hooks.base_hook import BaseHook
+from airflow.hooks.base import BaseHook
 
 class TtuHook(BaseHook, LoggingMixin):
     """
@@ -34,12 +34,23 @@ class TtuHook(BaseHook, LoggingMixin):
 
     extras example: ``{"bteq_quit_zero":true, "bteq_session_encoding";"UTF8"}``
     """
+    conn_name_attr = 'ttu_conn_id'
+    default_conn_name = 'ttu_default'
+    conn_type = 'ttu'
+    hook_name = 'TTU'
 
     def __init__(self, ttu_conn_id: str = 'ttu_default') -> None:
         super().__init__()
         self.ttu_conn_id = ttu_conn_id
         self.conn = None
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
+        if self.conn is not None:
+            self.close_conn()
+
     def get_conn(self) -> dict:
         if not self.conn:
             connection = self.get_connection(self.ttu_conn_id)
@@ -58,6 +69,13 @@ class TtuHook(BaseHook, LoggingMixin):
                 )
         return self.conn
 
+    def close_conn(self):
+        """
+        Closes the connection. An error will occur if the
+        connection wasn't ever opened.
+        """
+        self.conn = None
+
     def execute_bteq(self, bteq, xcom_push_flag=False):
         """
         Executes BTEQ sentences using BTEQ binary.
